setup_pyproject package — setup_pyproject unknown documentation

### Navigation

- index
- modules |
- next |
- previous |
- setup_pyproject unknown documentation »
- setup_pyproject »

# setup_pyproject package

## Subpackages

- setup_pyproject.templates package
  - Submodules
  - setup_pyproject.templates.authors module
  - setup_pyproject.templates.gitignore module
  - setup_pyproject.templates.manifest_in module
  - setup_pyproject.templates.readme module
  - setup_pyproject.templates.setup module
  - setup_pyproject.templates.sphinx_conf module
  - setup_pyproject.templates.sphinx_index module
  - setup_pyproject.templates.sphinx_makefile module
  - setup_pyproject.templates.versioneer module
  - Module contents

## Submodules

## setup_pyproject.info module

`setup_pyproject.info.` `email`()

`setup_pyproject.info.` `get_global_gitconfig`()

`setup_pyproject.info.` `username`()

## setup_pyproject.repo module

`setup_pyproject.repo.` `chdir`(*args, **kwds)

`setup_pyproject.repo.` `git_tree_add`(repo, struct, prefix=None)

`setup_pyproject.repo.` `init_commit_repo`(project, struct)

## setup_pyproject.runner module

`setup_pyproject.runner.` `main`(args)

`setup_pyproject.runner.` `parse_args`(args)

`setup_pyproject.runner.` `run`()

  Entry point for setup.py

## setup_pyproject.structure module

`setup_pyproject.structure.` `authors`()

`setup_pyproject.structure.` `create_structure`(struct, prefix=None)

`setup_pyproject.structure.` `gitignore`(args)

`setup_pyproject.structure.` `gitignore_all`()

`setup_pyproject.structure.` `make_structure`(args)

`setup_pyproject.structure.` `manifest_in`(args)

`setup_pyproject.structure.` `readme`(args)

`setup_pyproject.structure.` `setup`(args)

`setup_pyproject.structure.` `sphinx_conf`(args)

`setup_pyproject.structure.` `sphinx_index`(args)

`setup_pyproject.structure.` `sphinx_makefile`()

`setup_pyproject.structure.` `versioneer`()

## Module contents

### Navigation

- index
- modules |
- next |
- previous |
- setup_pyproject unknown documentation »
- setup_pyproject »